@@ -493,6 +493,10 @@ class AnnotationRecord(aspecd.utils.ToDictMixin):
     class_name : :class:`str`
         Fully qualified name of the class of the corresponding annotation
 
+    type : :class:`str`
+        Type of the annotation, usually similar to the class name but
+        human-readable and useful, *e.g.*, in reports.
+
     Parameters
     ----------
     annotation : :class:`aspecd.annotation.Annotation`
@@ -503,13 +507,18 @@ class AnnotationRecord(aspecd.utils.ToDictMixin):
     aspecd.annotation.MissingAnnotationError
         Raised when no annotation exists to act on
 
+
+    .. versionchanged:: 0.6
+        Added attribute :attr:`type`
+
     """
 
     def __init__(self, annotation=None):
         super().__init__()
         self.content = dict()
         self.class_name = ''
-        self._attributes_to_copy = ['content']
+        self.type = ''
+        self._attributes_to_copy = ['content', 'type']
         if annotation:
             self.from_annotation(annotation)
 
@@ -562,7 +571,7 @@ class AnnotationHistoryRecord(HistoryRecord):
 
     Attributes
     ----------
-    annotation : :class:`aspecd.analysis.Annotation`
+    annotation : :class:`aspecd.annotation.Annotation`
         Annotation the history is saved for
 
     package : :class:`str`
@@ -609,14 +618,22 @@ class PlotRecord(aspecd.utils.ToDictMixin):
         Name of the plotter.
 
         Defaults to the plotter class name and shall never be set manually.
+
     description : :class:`str`
         Short description of the plot
+
     parameters : :class:`dict`
         All parameters necessary for the plot, implicit and explicit
+
     properties : :class:`aspecd.plotting.PlotProperties`
         Properties of the plot, defining its appearance
+
     caption : :class:`aspecd.plotting.Caption`
         User-supplied information for the figure.
+
+    label : :class:`str`
+        Label used to reference figure, *e.g.* in context of a report
+
     filename : :class:`str`
         Name of the file the plot has been/should be saved to
 
@@ -631,6 +648,10 @@ class PlotRecord(aspecd.utils.ToDictMixin):
     aspecd.plotting.MissingPlotterError
         Raised if no plotter is provided.
 
+
+    .. versionchanged:: 0.6
+        New attribute :attr:`label`
+
     """
 
     def __init__(self, plotter=None):
@@ -640,9 +661,11 @@ class PlotRecord(aspecd.utils.ToDictMixin):
         self.parameters = dict()
         self.properties = None
         self.caption = None
+        self.label = ''
         self.filename = ''
         self._attributes_to_copy = ['description', 'parameters',
-                                    'properties', 'caption', 'filename']
+                                    'properties', 'caption', 'filename',
+                                    'label']
         if plotter:
             self.from_plotter(plotter=plotter)
 
